@@ -6,16 +6,94 @@ import xarray as xr
 from numpy.lib.recfunctions import rename_fields as np_rename_fields
 
 
+class lfnc(object):
+    def __init__(self, filename):
+
+        self.filename = filename
+
+        self.data = nc.Dataset(filename, "r")
+
+        self._attrs = self.data.ncattrs()
+
+        # ncdict = self.data.__dict__
+
+        self.tiles = list(self.data.groups)
+
+        self.vars = list(self.data[self.tiles[0]].variables)
+
+    def __del__(self):
+
+        self.data.close()
+
+    def get_attr(self, attr):
+
+        if attr not in self._attrs:
+            raise ValueError(f"Attribute {attr} not in netcdf file {self.filename}")
+
+        return self.data.getncattr(attr)
+
+    def to_xarray(
+        self, vars: Optional[list[str]] = None, chunk_size: Optional[int] = 10
+    ):
+
+        x_var = "x_distance" if "x_distance" in self.vars else "x"
+        y_var = "y_distance" if "y_distance" in self.vars else "y"
+
+        if vars is not None:
+            drop_variables = self.vars.copy()
+            for v in vars + [x_var, y_var]:
+                drop_variables.remove(v)
+        else:
+            drop_variables = []
+
+        data = xr.open_dataset(
+            self.filename, group=self.tiles[0], drop_variables=drop_variables
+        )
+
+        tile_chunks = [
+            self.tiles[i * chunk_size : (i + 1) * chunk_size]
+            for i in range((len(self.tiles) + chunk_size - 1) // chunk_size)
+        ]
+
+        d = []
+
+        for k, chunk in enumerate(tile_chunks):
+            d.append(
+                xr.open_dataset(
+                    self.filename, group=chunk[0], drop_variables=drop_variables
+                )
+            )
+            for t in chunk[1:]:
+                d_tmp = xr.open_dataset(
+                    self.filename, group=t, drop_variables=drop_variables
+                )
+                d[k] = d[k].combine_first(d_tmp)
+
+        data = xr.merge(d)
+
+        if x_var == "x_distance":
+            data = data.rename({"x_distance": "x"})
+        if y_var == "y_distance":
+            data = data.rename({"y_distance": "y"})
+
+        return data
+
+
 def nc_vars(filename):
     with nc.Dataset(filename, "r") as rgrp:
-        attrs = rgrp.__dict__
-
         tiles = list(rgrp.groups)
         nc_variables = list(rgrp[tiles[0]].variables)
 
     return nc_variables
 
 
+def nc_attrs(filename):
+    with nc.Dataset(filename, "r") as rgrp:
+        attrs = rgrp.ncattrs()
+
+    return attrs
+
+
 def nc_get_tiles(filename):
     with nc.Dataset(filename, "r") as rgrp:
         attrs = rgrp.__dict__
