@@ -2,6 +2,13 @@ from numpy import log10
 from math import ceil
 import utm
 
+import os
+import shutil
+
+import gzip
+import tarfile
+import zipfile
+
 def _nice_round(val):
 	from numpy import log10
 	from math import ceil
@@ -39,6 +46,18 @@ def _file_in_zip(fileName,zipRef):
 def _path_of_file_in_zip(fileName,zipRef):
 	return [s for s in zipRef.namelist() if fileName in s]
 
+def _decompress_gz(fileIn):
+	filename, fileext = os.path.splitext(fileIn)
+
+	if fileext != '.gz':
+		raise ValueError('In _decompress_gz, {} must have extension .gz'.format(fileIn))
+	
+	with gzip.open(fileIn, 'rb') as f_in:
+		with open(filename, 'wb') as f_out:
+			shutil.copyfileobj(f_in, f_out)
+	
+	return filename
+
 def csv_active_cols(filename):
 	with open(filename) as f:
 		header = f.readline()
